"""
"""
__version__ = '4.2.2'

# Instantiate before the CLI
from mlky.configs import *
from mlky         import cli
